.float-right {
  float: right;
}

.warning {
  color: red;
  background: transparent url(../images/admin-tools.png) 0 -412px no-repeat;
  padding-left: 25px;
}

.dashboard #content {
  display: block;
  width: auto;
  margin: 15px 5px;
}

.dashboard-container {
  clear: both;
}

h1.dashboard-title {
  float: left;
  padding-bottom: 0;
  margin: 0 10px;
}

#dashboard-panel {
  margin: 0 10px 0 0;
  float: right;
}

#dashboard-panel h3 a {
  padding: 5px;
  min-width: 100px;
  display: block;
  text-align: center;
  border: 1px solid var(--border-color);
}

#dashboard-panel ul {
  display: none;
  position: absolute;
  top: auto;
  right: 25px;
  margin-top: -1px;
}

#dashboard-panel ul li {
  padding: 5px;
  border: 1px solid var(--border-color);
  background-color: var(--body-bg);
}

#dashboard-panel ul li a {
  display: block;
}

#dashboard-panel:hover ul {
  display: block;
}

.dashboard ul {
  margin: 0;
  padding: 0;
  list-style: none;
}

.dashboard ul li {
  list-style: none;
}

.dashboard-column {
  width: 49.9%;
  float: left;
  min-height: 200px;
}

.dashboard-module {
  margin: 10px 10px 5px;
  padding: 0;
}

.dashboard-placeholder {
  background-color: var(--body-bg);
  margin: 10px 10px 5px;
}

.dashboard-module h2 {
  margin: 0;
  padding: 7px 5px 8px 8px;
  text-align: left;
  font-weight: normal;
  background: var(--darkened-bg);
  height: 20px;
  color: var(--body-quiet-color);
}

.dashboard-module.draggable h2 {
  cursor: move;
}

.dashboard-module h2 a.toggle-icon,
.dashboard-module h2 a.close-icon {
  text-indent: -9999px;
  display: block;
  float: right;
  height: 20px;
  width: 17px;
  margin: 0 0 0 5px;
  cursor: pointer;
  background-image: url(../images/admin-tools.png);
  background-repeat: no-repeat;
}

.dashboard-module h2 a.toggle-icon {
  background-position: 0 -45px;
}

.dashboard-module h2 a.toggle-icon.collapsed {
  background-position: 0 -85px;
}

.dashboard-module h2 a.toggle-icon.collapsed:hover {
  background-position: 0 -105px;
}

.dashboard-module h2 a.close-icon {
  background-position: 0 -125px;
}

.fixed h2 span.toggle-icon,
.fixed h2 span.close-icon {
  display: none;
}

.dashboard-module h3 {
  padding: 5px 8px;
  margin: 0;
  background: var(--primary);
  color: var(--header-link-color);
}

.dashboard-module h3 a {
  margin: 0;
  color: var(--header-link-color);
  font-size: 13px;
  font-weight: normal;
}

.dashboard-module-content {
  border-top: 1px solid var(--border-color);
  background: var(--darkened-bg);
}

.dashboard-module-content p {
  margin: 10px;
}

.dashboard-module ul li {
  padding: 5px 8px;
}

.dashboard-module ul li a.external-link {
  background-image: url(../images/admin-tools.png);
  background-repeat: no-repeat;
  background-position: -5px -168px;
  padding-left: 15px;
}

.dashboard-module ul li.odd {
  background: var(--body-bg);
}

.dashboard-module ul li.even {
  background: var(--darkened-bg);
}

.dashboard-module ul li:hover {
  background-color: var(--dashboard-li-hover);
}

.dashboard-module ul li ul {
  float: right;
}

.dashboard-module ul li ul li {
  display: block;
  float: left;
  border: 0;
  padding: 0 5px;
  vertical-align: top;
  height: auto;
}

.dashboard-module ul.inline {
  display: block;
  height: auto;
  padding: 15px;
  text-align: center;
}

.dashboard-module ul.inline li {
  display: inline;
  margin: 10px auto;
}

.dashboard-module ul.inline li.odd,
.dashboard-module ul.inline li.even {
  background: none;
}


.group {
  border: 0;
  margin: 0;
  padding: 0;
}

.group ul {
  background: none;
  background-color: var(--body-bg);
  border-width: 0 0 1px;
  border-color: var(--border-color);
}

.group ul li.group-tabs-link {
  margin-top: 7px;
}

.group ul li.group-tabs-link a:focus,
.group ul li.group-tabs-link a:active {
  border: none;
  outline: none;
}

.group .dashboard-module {
  padding: 5px;
  margin: 0;
}

.group-accordion .group-accordion-header {
  display: block;
  clear: both;
  border-bottom: 1px solid var(--border-color);
  margin: 0;
  background: none;
}

.group-accordion .dashboard-module {
  border: 0;
}
