{% extends "admin/change_list_object_tools.html" %}

{% block object-tools-items %}
  {% for tool in changelist_tools %}
    <li>{{ tool.html }}</li>
  {% endfor %}
  {{ block.super }}
{% endblock %}
