#header {
  overflow: visible;
  min-height: 67px;
  display: block;
  padding: 0;
}

div.breadcrumbs {
  clear: both;
}

#header #branding h1 {
  margin: 0;
  padding: 5px 10px;
  height: 31px;
}

#header #bookmark-form {
  clear: both;
}

#header ul {
  list-style: none;
  margin: 0;
  padding: 0;
  z-index: 9999;
}

#header ul li {
  position: relative;
  list-style: none;
}

#header ul li a {
  white-space: nowrap;
}

#header #user-tools {
  padding-right: 1.2em;
  height: 40px;
  display: flex;
  align-items: center;
}

#header #navigation-menu {
  height: 30px;
  z-index: 9999;
  border-top: 1px solid var(--primary);
  border-bottom: 1px solid var(--primary);
  clear: both;
  display: flex;
}

#header #bookmark-button {
  cursor: pointer;
  position: absolute;
  top: auto;
  right: 15px;
  height: 25px;
  width: 24px;
  margin-top: 4px;
  border: none;
  text-indent: -5000px;
  overflow: hidden;
  background: transparent url(../images/admin-tools.png) no-repeat 0 -425px;
}

#header #bookmark-button.bookmarked {
  background-position: 0 -445px;
}

#header ul#navigation-menu li {
  float: left;
  line-height: 14px;
  padding: 0;
}

#header ul#navigation-menu li a {
  display: block;
  text-transform: uppercase;
  text-decoration: none;
  padding: 8px 30px 8px 15px;
  border-right: 1px solid var(--primary);
}

#header ul#navigation-menu li a.has-icon:after {
  content: '';
  position: absolute;
  right: 10px;
  height: 10px;
  width: 20px;
  background: transparent url(../images/admin-tools.png) no-repeat 0 -360px;
}

#header ul#navigation-menu li.disabled a {
  color: #bbb;
  cursor: default;
}

#header ul#navigation-menu li.first a {
  margin: 0 0 0 12px;
  text-indent: 14px;
  background: transparent url(../images/admin-tools.png) no-repeat 0 -382px;
}

#header ul#navigation-menu li:hover,
#header ul#navigation-menu li.over,
#header ul#navigation-menu li.selected {
  background: var(--header-bg);
}

#header ul#navigation-menu li ul {
  display: none;
  position: absolute;
  top: auto;
  left: auto;
  margin-left: -1px;
}

#header ul#navigation-menu li ul li {
  padding: 0;
  float: none;
  background: none;
  z-index: 9999;
}

#header ul#navigation-menu li ul li a {
  display: block;
  border: 1px solid var(--secondary);
  border-width: 0 1px 1px 1px;
  text-transform: none;
}

#header ul#navigation-menu li ul li a.has-icon:after {
  background-position: 0 -370px;
}

#header ul#navigation-menu li ul li ul {
  left: 100%;
  top: 0;
  border-top: 1px solid var(--secondary);
}

#header ul#navigation-menu li ul li ul li a {
  white-space: nowrap;
}

#header ul#navigation-menu li:hover ul li ul,
#header ul#navigation-menu li.over ul li ul {
  display: none;
}

#header ul#navigation-menu li:hover > ul,
#header ul#navigation-menu li.over > ul,
#header ul#navigation-menu li ul li:hover > ul,
#header ul#navigation-menu li ul li.over > ul {
  display: block;
}

#header ul#navigation-menu li:hover > ul li,
#header ul#navigation-menu li.over > ul li,
#header ul#navigation-menu li ul li:hover > ul li,
#header ul#navigation-menu li ul li.over > ul li {
  background: var(--button-bg);
}

#header ul#navigation-menu li ul li:hover,
#header ul#navigation-menu li ul li.over,
#header ul#navigation-menu li ul li ul li:hover,
#header ul#navigation-menu li ul li ul li.over {
  background: var(--button-hover-bg);
}

#header ul#navigation-menu li.disabled a:hover,
#header ul#navigation-menu li.disabled a.over {
  background: none;
}

#content {
  clear: both;
}
